diff --git a/spring-context/src/test/java/org/springframework/context/support/EnvironmentIntegrationTests.java b/spring-context/src/test/java/org/springframework/context/support/EnvironmentIntegrationTests.java
index 1dabca831d..ed9aed046e 100644
--- a/spring-context/src/test/java/org/springframework/context/support/EnvironmentIntegrationTests.java
+++ b/spring-context/src/test/java/org/springframework/context/support/EnvironmentIntegrationTests.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -28,9 +28,11 @@ import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.*;
/**
- * Tests covering the integration of {@link Environment} into {@link ApplicationContext} hierarchies.
+ * Tests covering the integration of the {@link Environment} into
+ * {@link ApplicationContext} hierarchies.
*
* @author Chris Beams
+ * @see org.springframework.core.env.EnvironmentSystemIntegrationTests
*/
public class EnvironmentIntegrationTests {
@@ -48,6 +50,9 @@ public class EnvironmentIntegrationTests {
sameInstance(parent.getEnvironment()),
sameInstance(child.getEnvironment())));
assertThat("expected child ctx env", env, sameInstance(child.getEnvironment()));
+
+ child.close();
+ parent.close();
}
}
diff --git a/src/test/java/org/springframework/core/env/scan1/package-info.java b/src/test/java/org/springframework/core/env/scan1/package-info.java
index d2a554752a..0bfa7e043e 100644
--- a/src/test/java/org/springframework/core/env/scan1/package-info.java
+++ b/src/test/java/org/springframework/core/env/scan1/package-info.java
@@ -20,8 +20,8 @@
*/
package org.springframework.core.env.scan1;
-import static org.springframework.core.env.EnvironmentIntegrationTests.Constants.DEV_ENV_NAME;
-import static org.springframework.core.env.EnvironmentIntegrationTests.Constants.PROD_ENV_NAME;
+import static org.springframework.core.env.EnvironmentSystemIntegrationTests.Constants.DEV_ENV_NAME;
+import static org.springframework.core.env.EnvironmentSystemIntegrationTests.Constants.PROD_ENV_NAME;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
diff --git a/src/test/java/org/springframework/core/env/scan2/package-info.java b/src/test/java/org/springframework/core/env/scan2/package-info.java
index be66aa076a..1202c8184b 100644
--- a/src/test/java/org/springframework/core/env/scan2/package-info.java
+++ b/src/test/java/org/springframework/core/env/scan2/package-info.java
@@ -20,10 +20,10 @@
*/
package org.springframework.core.env.scan2;
-import static org.springframework.core.env.EnvironmentIntegrationTests.Constants.DEV_BEAN_NAME;
-import static org.springframework.core.env.EnvironmentIntegrationTests.Constants.DEV_ENV_NAME;
-import static org.springframework.core.env.EnvironmentIntegrationTests.Constants.PROD_BEAN_NAME;
-import static org.springframework.core.env.EnvironmentIntegrationTests.Constants.PROD_ENV_NAME;
+import static org.springframework.core.env.EnvironmentSystemIntegrationTests.Constants.DEV_BEAN_NAME;
+import static org.springframework.core.env.EnvironmentSystemIntegrationTests.Constants.DEV_ENV_NAME;
+import static org.springframework.core.env.EnvironmentSystemIntegrationTests.Constants.PROD_BEAN_NAME;
+import static org.springframework.core.env.EnvironmentSystemIntegrationTests.Constants.PROD_ENV_NAME;
import org.springframework.context.annotation.Profile;
import org.springframework.stereotype.Component;
diff --git a/src/test/resources/org/springframework/core/env/EnvironmentIntegrationTests-context-dev.xml b/src/test/resources/org/springframework/core/env/EnvironmentSystemIntegrationTests-context-dev.xml
similarity index 100%
rename from src/test/resources/org/springframework/core/env/EnvironmentIntegrationTests-context-dev.xml
rename to src/test/resources/org/springframework/core/env/EnvironmentSystemIntegrationTests-context-dev.xml
diff --git a/src/test/resources/org/springframework/core/env/EnvironmentIntegrationTests-context-prod.xml b/src/test/resources/org/springframework/core/env/EnvironmentSystemIntegrationTests-context-prod.xml
similarity index 100%
rename from src/test/resources/org/springframework/core/env/EnvironmentIntegrationTests-context-prod.xml
rename to src/test/resources/org/springframework/core/env/EnvironmentSystemIntegrationTests-context-prod.xml
diff --git a/src/test/resources/org/springframework/core/env/EnvironmentIntegrationTests-context.xml b/src/test/resources/org/springframework/core/env/EnvironmentSystemIntegrationTests-context.xml
similarity index 76%
rename from src/test/resources/org/springframework/core/env/EnvironmentIntegrationTests-context.xml
rename to src/test/resources/org/springframework/core/env/EnvironmentSystemIntegrationTests-context.xml
index 1ebf65c89a..0fcafe09e4 100644
--- a/src/test/resources/org/springframework/core/env/EnvironmentIntegrationTests-context.xml
+++ b/src/test/resources/org/springframework/core/env/EnvironmentSystemIntegrationTests-context.xml
@@ -3,9 +3,9 @@
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xsi:schemaLocation="http://www.springframework.org/schema/beans http://www.springframework.org/schema/beans/spring-beans.xsd">
-
+
-
-
+
+
diff --git a/src/test/java/org/springframework/core/env/EnvironmentIntegrationTests.java b/src/test/java/org/springframework/core/env/EnvironmentSystemIntegrationTests.java
similarity index 95%
rename from src/test/java/org/springframework/core/env/EnvironmentIntegrationTests.java
rename to src/test/java/org/springframework/core/env/EnvironmentSystemIntegrationTests.java
index 6795d24ab9..f55fab3c1c 100644
--- a/src/test/java/org/springframework/core/env/EnvironmentIntegrationTests.java
+++ b/src/test/java/org/springframework/core/env/EnvironmentSystemIntegrationTests.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
package org.springframework.core.env;
+
import java.io.File;
import java.io.IOException;
@@ -65,43 +66,40 @@ import static org.hamcrest.Matchers.*;
import static org.junit.Assert.*;
import static org.springframework.beans.factory.support.BeanDefinitionBuilder.*;
import static org.springframework.context.ConfigurableApplicationContext.*;
-import static org.springframework.core.env.EnvironmentIntegrationTests.Constants.*;
+import static org.springframework.core.env.EnvironmentSystemIntegrationTests.Constants.*;
/**
- * Integration tests for container support of {@link Environment}
- * interface.
+ * System integration tests for container support of the {@link Environment} API.
*
- * Tests all existing BeanFactory and ApplicationContext implementations to
- * ensure that:
- * - a standard environment object is always present
- * - a custom environment object can be set and retrieved against the factory/context
- * - the {@link EnvironmentAware} interface is respected
- * - the environment object is registered with the container as a singleton
- * bean (if an ApplicationContext)
- * - bean definition files (if any, and whether XML or @Configuration) are
- * registered conditionally based on environment metadata
+ *
+ * Tests all existing BeanFactory and ApplicationContext implementations to ensure that:
+ *
+ * - a standard environment object is always present
+ *
- a custom environment object can be set and retrieved against the factory/context
+ *
- the {@link EnvironmentAware} interface is respected
+ *
- the environment object is registered with the container as a singleton bean (if an
+ * ApplicationContext)
+ *
- bean definition files (if any, and whether XML or @Configuration) are registered
+ * conditionally based on environment metadata
+ *
*
* @author Chris Beams
+ * @author Sam Brannen
+ * @see org.springframework.context.support.EnvironmentIntegrationTests
*/
@SuppressWarnings("resource")
-public class EnvironmentIntegrationTests {
-
- private ConfigurableEnvironment prodEnv;
+public class EnvironmentSystemIntegrationTests {
- private ConfigurableEnvironment devEnv;
+ private final ConfigurableEnvironment prodEnv = new StandardEnvironment();
- private ConfigurableEnvironment prodWebEnv;
+ private final ConfigurableEnvironment devEnv = new StandardEnvironment();
+ private final ConfigurableEnvironment prodWebEnv = new StandardServletEnvironment();
@Before
public void setUp() {
- prodEnv = new StandardEnvironment();
prodEnv.setActiveProfiles(PROD_ENV_NAME);
-
- devEnv = new StandardEnvironment();
devEnv.setActiveProfiles(DEV_ENV_NAME);
-
- prodWebEnv = new StandardServletEnvironment();
prodWebEnv.setActiveProfiles(PROD_ENV_NAME);
}
@@ -640,8 +638,8 @@ public class EnvironmentIntegrationTests {
/**
* Mirrors the structure of beans and environment-specific config files
* in EnvironmentIntegrationTests-context.xml
*/
@Configuration
@Import({DevConfig.class, ProdConfig.class})
@@ -694,7 +692,7 @@ public class EnvironmentIntegrationTests {
*/
public static class Constants {
- public static final String XML_PATH = "org/springframework/core/env/EnvironmentIntegrationTests-context.xml";
+ public static final String XML_PATH = "org/springframework/core/env/EnvironmentSystemIntegrationTests-context.xml";
public static final String ENVIRONMENT_AWARE_BEAN_NAME = "envAwareBean";
@@ -640,8 +638,8 @@ public class EnvironmentIntegrationTests {
/**
- * Mirrors the structure of beans and environment-specific config files
- * in EnvironmentIntegrationTests-context.xml
+ * Mirrors the structure of beans and environment-specific config files in
+ * EnvironmentSystemIntegrationTests-context.xml
*/